#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Times Series
# 
# Material for the hackathon ENSAE / Red Cross / 2015. Extract and plot a time series.

# In[1]:


get_ipython().run_line_magic('matplotlib', 'inline')
import matplotlib.pyplot as plt
plt.style.use('ggplot')


# In[2]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ## Connection to the cluster

# In[3]:


from pyquickhelper.loghelper import get_password
hackathon = {}
hackathon["blob_storage"] = get_password("CRCREDENTIALS", "blobstorage")
hackathon["password"] = get_password("CRCREDENTIALS", "password")


# In[4]:


blobstorage = hackathon["blob_storage"]
blobpassword = hackathon["password"]


# In[5]:


get_ipython().run_line_magic('load_ext', 'pyensae')


# In[6]:


cl, bs = get_ipython().run_line_magic('blob_open', '')
cl, bs


# ## Download data

# In[7]:


get_ipython().run_line_magic('blob_ls', 'croix-rouge')


# In[8]:


get_ipython().run_line_magic('blob_down', 'croix-rouge/data/SINVOICE.schema.txt SINVOICE.schema.txt')


# In[9]:


import pandas
df = pandas.read_csv("SINVOICE.schema.txt", sep="\t", encoding="utf8")
df.to_excel("SINVOICE.schema.xlsx")
df.head(n=1)


# In[10]:


get_ipython().run_line_magic('blob_down', 'croix-rouge/data/SINVOICE_.txt SINVOICE_.txt')


# ## Operations, conversion, and some others stuff

# ### change encoding

# In[11]:


from ensae_projects.datainc import change_encoding
change_encoding("SINVOICE_.txt", "SINVOICE_.utf8.txt", enc1="latin-1")


# In[12]:


import pyensae
get_ipython().run_line_magic('head', 'SINVOICE_.utf8.txt --n=2')


# ### enumerate rows as dictionary

# In[13]:


from ensae_projects.datainc import enumerate_text_lines
def clean_column_name(s):
    return s.replace("_0", "")
for i, row in enumerate(enumerate_text_lines("SINVOICE_.utf8.txt", 
                                             encoding="utf-8", header=True, quotes_as_str=True,
                       clean_column_name=clean_column_name)):
    
    print(list(sorted(row.keys()))) 
    break
       


# ### select a few columns and look at them

# In[14]:


bigfile = enumerate_text_lines("SINVOICE_.utf8.txt", encoding="utf-8", header=True, quotes_as_str=True,
                              clean_column_name=clean_column_name, fLOG=print)


# In[15]:


l = map(lambda row: { "BPR":row["BPR"], "BPRDAT":row["BPRDAT"]}, bigfile)


# In[16]:


l = list(l)
len(l)


# In[17]:


import pandas
df = pandas.DataFrame(l)


# In[18]:


df.head()


# In[19]:


df.groupby("BPRDAT").count().plot()


# In[20]: